Installation
============


The cartes library is accessible through conda (recommended):

.. code:: bash

    conda install -c conda-forge cartes

or with pip:

.. code:: bash

    pip install cartes


The development version may be installed after cloning the GitHub repository:

.. code:: bash

    git clone https://github.com/xoolive/cartes
    cd cartes/
    pip install .
